==> agrosyst-cli-1.3.0.1-sources.jar: fr/inra/agrosyst/services/imprt/domain/DomainImportDto.java <==
package fr.inra.agrosyst.services.imprt.domain;

/*
 * #%L
 * Agrosyst :: Services
 * $Id: DomainImportDto.java 4440 2014-10-16 17:25:26Z dcosse $
 * $HeadURL: https://svn.codelutin.com/agrosyst/tags/agrosyst-1.3.0.1/agrosyst-cli/src/main/java/fr/inra/agrosyst/services/imprt/domain/DomainImportDto.java $
 * %%
 * Copyright (C) 2013 - 2014 INRA
 * %%
 * INRA - Tous droits réservés
 * #L%
 */
import fr.inra.agrosyst.api.entities.DomainImpl;

public class DomainImportDto extends DomainImpl {

    /**
     * serialVersionUID.
     */
    private static final long serialVersionUID = 8435193675746925772L;

    public static final String PROPERTY_ID = "id";
    public static final String PROPERTY_LOCATION_ID = "locationId";
    public static final String PROPERTY_LEGAL_STATUS_ID = "legalStatusId";
    public static final String PROPERTY_OTEX18_ID = "refOtex18Id";
    public static final String PROPERTY_OTEX70_ID = "refOtex70Id";
    public static final String PROPERTY_DEFAULT_WEATHER_STATION_ID = "defaultWeatherStationId";

    private String id;
    private String locationId;
    private String legalStatusId;
    private String refOtex18Id;
    private String refOtex70Id;
    private String defaultWeatherStationId;

    public String getDefaultWeatherStationId() {
        return defaultWeatherStationId;
    }

    public void setDefaultWeatherStationId(String defaultWeatherStationId) {
        this.defaultWeatherStationId = defaultWeatherStationId;
    }

    public String getRefOtex18Id() {
        return refOtex18Id;
    }

    public void setRefOtex18Id(String refOtex18Id) {
        this.refOtex18Id = refOtex18Id;
    }

    public String getRefOtex70Id() {
        return refOtex70Id;
    }

    public void setRefOtex70Id(String refOtex70Id) {
        this.refOtex70Id = refOtex70Id;
    }

    public String getLegalStatusId() {
        return legalStatusId;
    }

    public void setLegalStatusId(String legalStatusId) {
        this.legalStatusId = legalStatusId;
    }

    public String getLocationId() {
        return locationId;
    }

    public void setLocationId(String locationId) {
        this.locationId = locationId;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

}

==> agrosyst-cli-1.3.1-sources.jar: fr/inra/agrosyst/services/imprt/domain/DomainImportDto.java <==
package fr.inra.agrosyst.services.imprt.domain;

/*
 * #%L
 * Agrosyst :: Services
 * $Id: DomainImportDto.java 4440 2014-10-16 17:25:26Z dcosse $
 * $HeadURL: https://svn.codelutin.com/agrosyst/tags/agrosyst-1.3.1/agrosyst-cli/src/main/java/fr/inra/agrosyst/services/imprt/domain/DomainImportDto.java $
 * %%
 * Copyright (C) 2013 - 2014 INRA
 * %%
 * INRA - Tous droits réservés
 * #L%
 */
import fr.inra.agrosyst.api.entities.DomainImpl;

public class DomainImportDto extends DomainImpl {

    /**
     * serialVersionUID.
     */
    private static final long serialVersionUID = 8435193675746925772L;

    public static final String PROPERTY_ID = "id";
    public static final String PROPERTY_LOCATION_ID = "locationId";
    public static final String PROPERTY_LEGAL_STATUS_ID = "legalStatusId";
    public static final String PROPERTY_OTEX18_ID = "refOtex18Id";
    public static final String PROPERTY_OTEX70_ID = "refOtex70Id";
    public static final String PROPERTY_DEFAULT_WEATHER_STATION_ID = "defaultWeatherStationId";

    private String id;
    private String locationId;
    private String legalStatusId;
    private String refOtex18Id;
    private String refOtex70Id;
    private String defaultWeatherStationId;

    public String getDefaultWeatherStationId() {
        return defaultWeatherStationId;
    }

    public void setDefaultWeatherStationId(String defaultWeatherStationId) {
        this.defaultWeatherStationId = defaultWeatherStationId;
    }

    public String getRefOtex18Id() {
        return refOtex18Id;
    }

    public void setRefOtex18Id(String refOtex18Id) {
        this.refOtex18Id = refOtex18Id;
    }

    public String getRefOtex70Id() {
        return refOtex70Id;
    }

    public void setRefOtex70Id(String refOtex70Id) {
        this.refOtex70Id = refOtex70Id;
    }

    public String getLegalStatusId() {
        return legalStatusId;
    }

    public void setLegalStatusId(String legalStatusId) {
        this.legalStatusId = legalStatusId;
    }

    public String getLocationId() {
        return locationId;
    }

    public void setLocationId(String locationId) {
        this.locationId = locationId;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

}
